<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Multi_Insure
 */

?>
<!doctype html>
	<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php wp_head(); ?>
	</head>

	<body <?php body_class(); ?>>

		<?php wp_body_open(); ?>
		<div id="page" class="site">

			<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'multi-insure' ); ?></a>

			<header id="masthead" class="site-header">
				<?php if ( get_theme_mod( 'multi_insure_enable_topbar', false ) === true ) { ?>
				<div class="multi-insure-top-header">
					<div class="multi-insure-wrapper">
						<div class="multi-insure-top-header-wrapper">
							<?php
							$topbar_text = get_theme_mod( 'multi_insure_topbar_notice_text', '' );
							if ( ! empty( $topbar_text ) ) {
								?>
								<div class="multi-insure-top-header-left">
									<div class="top-left-header-container">
										<p><?php echo esc_html( $topbar_text ); ?></p>
									</div>
								</div>
							<?php } ?>	
							<div class="multi-insure-top-header-right">
								<div class="top-right-header-container">
									<?php
									if ( has_nav_menu( 'social' ) ) {
										wp_nav_menu(
											array(
												'container'         => 'ul',
												'menu_class'        => 'social-links',
												'theme_location'    => 'social',
												'link_before'       => '<span class="screen-reader-text">',
												'link_after'        => '</span>',
											)
										);
									}
									?>
								</div>
							</div>
						</div>	
					</div>
				</div>
				<?php } ?>
				<div class="multi-insure-middle-header">
					<div class="multi-insure-wrapper">
						<div class="multi-insure-middle-header-wrapper">
							<div class="site-branding">
								<?php if ( has_custom_logo() ) { ?>
								<div class="site-logo">
									<?php the_custom_logo(); ?>
								</div>
								<?php } ?>
								<div class="site-identity">
									<?php
									if ( is_front_page() && is_home() ) :
										?>
									<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
										<?php
									else :
										?>
										<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
										<?php
									endif;
									$multi_insure_description = get_bloginfo( 'description', 'display' );
									if ( $multi_insure_description || is_customize_preview() ) :
										?>
										<p class="site-description"><?php echo $multi_insure_description; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
									<?php endif; ?>
								</div>	
							</div>
							<div class="multi-insure-brand-contact-wrapper">
								<?php
								$email_id     = get_theme_mod( 'multi_insure_email_address', '' );
								$contact_no   = get_theme_mod( 'multi_insure_contact_number', '' );
								$opening_time = get_theme_mod( 'multi_insure_opening_time', '' );
								$closing_time = get_theme_mod( 'multi_insure_closing_time', '' );
								if ( ! empty( $email_id || $contact_no ) ) {
									?>
								<div class="multi-insure-brand-contact">
									<div class="brand-contact-logo">
										<i class="fa fa-mobile" aria-hidden="true"></i>
									</div>
									<div class="brand-contact-info">
										<ul>
											<li><a href="mailto:<?php echo esc_attr( $email_id ); ?>"><?php echo esc_html( $email_id ); ?></a></li>
											<li><a href="tel:<?php echo esc_attr( $contact_no ); ?>"><?php echo esc_html( $contact_no ); ?></a></li>
										</ul>
									</div>
								</div>
								<?php } ?>
								<?php if ( ! empty( $opening_time || $closing_time ) ) { ?>
								<div class="multi-insure-brand-time">
									<div class="brand-opening-logo">
										<i class="fa fa-clock-o" aria-hidden="true"></i>
									</div>
									<div class="brand-opening-time">
									<ul>
										<?php if ( ! empty( $opening_time ) ) { ?>
											<li><p><?php echo esc_html( $opening_time ); ?></p></li>
											<?php
										}
										if ( ! empty( $closing_time ) ) {
											?>
											<li><p><?php echo esc_html( $closing_time ); ?></p></li>
										<?php } ?>
									</ul>
									</div>
								</div>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>		
				<!-- end of site-branding -->
				<div class="multi-insure-navigation">
					<div class="multi-insure-wrapper"> 
						<div class="multi-insure-navigation-container">
							<nav id="site-navigation" class="main-navigation">
								<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
									<span class="ham-icon"></span>
									<span class="ham-icon"></span>
									<span class="ham-icon"></span>
									<i class="fa fa-bars" aria-hidden="true"></i>
								</button>
								<div class="navigation-area">
									<?php
									if ( has_nav_menu( 'primary' ) ) {
										wp_nav_menu(
											array(
												'theme_location' => 'primary',
												'menu_id'        => 'primary-menu',
											)
										);
									}
									?>
									<div class="multi-insure-brand-contact-wrapper">
										<div class="multi-insure-brand-contact">
											<?php
											$email_id   = get_theme_mod( 'multi_insure_email_address', '' );
											$contact_no = get_theme_mod( 'multi_insure_contact_number', '' );
											?>
											<?php if ( ! empty( $contact_no ) ) { ?>
												<div class="brand-phone">
													<div class="brand-contact-logo">
														<i class="fa fa-mobile" aria-hidden="true"></i>
													</div>
													<div class="brand-contact-info">
													<a href="tel:<?php echo esc_attr( $contact_no ); ?>"><?php echo esc_html( $contact_no ); ?></a>
													</div>
												</div>
												<?php
											}
											if ( ! empty( $email_id ) ) {
												?>
												<div class="brand-mail">
													<div class="brand-mail-logo">
														<i class="fa fa-envelope-o" aria-hidden="true"></i>
													</div>
													<div class="brand-mail-info">
														<a href="mailto:<?php echo esc_attr( $email_id ); ?>"><?php echo esc_html( $email_id ); ?></a>
													</div>
												</div>
											<?php } ?>
										</div>
									</div>

									<div class="multi-insure-brand-time-wrapper">
										<div class="multi-insure-brand-time-container">
											<?php
											$opening_time = get_theme_mod( 'multi_insure_opening_time', '' );
											$closing_time = get_theme_mod( 'multi_insure_closing_time', '' );
											?>
											<div class="multi-insure-brand-time">
												<div class="brand-opening-logo">
													<i class="fa fa-clock-o" aria-hidden="true"></i>
												</div>
												<div class="brand-opening-time">
													<ul>
														<?php if ( ! empty( $opening_time ) ) { ?>
															<li><p><?php echo esc_html( $opening_time ); ?></p></li>
															<?php
														}
														if ( ! empty( $closing_time ) ) {
															?>
															<li><p><?php echo esc_html( $closing_time ); ?></p></li>
														<?php } ?>
													</ul>
												</div>
											</div>
										</div>
									</div>
								</div>
							</nav><!-- #site-navigation -->
							<!-- start of search bar -->
							<div class="multi-insure-header-search">
								<div class="header-search-wrap">
									<a href="#" class="search-icon"><i class="fa fa-search" aria-hidden="true"></i></a>
									<div class="header-search-form">
										<?php get_search_form(); ?>
									</div>
								</div>
							</div>
							<!-- end of search bar -->
						</div>
					</div>
				</div>
			</header><!-- #masthead -->

		<?php if ( ! is_front_page() || is_home() ) { ?>
			<div class="multi-insure-main-wrapper">
				<div class="multi-insure-wrapper">
					<div class="multi-insure-container-wrapper">
					<?php } ?>
