<?php
/**
 * About Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_about_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'About Us Section', 'multi-insure' ),
		'priority' => 20,
	)
);

// About Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_about_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_about_section',
		array(
			'label'    => esc_html__( 'Enable About Section', 'multi-insure' ),
			'section'  => 'multi_insure_about_section',
			'settings' => 'multi_insure_enable_about_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_about_section',
		array(
			'selector' => '#multi_insure_about_section .section-link',
			'settings' => 'multi_insure_enable_about_section',
		)
	);
}

// About Section - Content Type.
$wp_customize->add_setting(
	'multi_insure_about_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_about_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'multi-insure' ),
		'section'         => 'multi_insure_about_section',
		'settings'        => 'multi_insure_about_content_type',
		'type'            => 'select',
		'active_callback' => 'multi_insure_is_about_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'multi-insure' ),
			'post' => esc_html__( 'Post', 'multi-insure' ),
		),
	)
);

// About Section - Section Subtitle.
$wp_customize->add_setting(
	'multi_insure_about_section_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_about_section_subtitle',
	array(
		'label'           => esc_html__( 'About Subtitle', 'multi-insure' ),
		'section'         => 'multi_insure_about_section',
		'settings'        => 'multi_insure_about_section_subtitle',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_about_section_enabled',
	)
);

// About Section - Content Type Post.
$wp_customize->add_setting(
	'multi_insure_about_content_post',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'multi_insure_about_content_post',
	array(
		'section'         => 'multi_insure_about_section',
		'settings'        => 'multi_insure_about_content_post',
		'label'           => esc_html__( 'Select Post', 'multi-insure' ),
		'type'            => 'select',
		'choices'         => multi_insure_get_post_choices(),
		'active_callback' => 'multi_insure_is_about_section_and_content_type_post_enabled',
	)
);

// About Section - Content Type Page.
$wp_customize->add_setting(
	'multi_insure_about_content_page',
	array(
		'sanitize_callback' => 'absint',
	)
);

$wp_customize->add_control(
	'multi_insure_about_content_page',
	array(
		'label'           => esc_html__( 'Select Page', 'multi-insure' ),
		'section'         => 'multi_insure_about_section',
		'settings'        => 'multi_insure_about_content_page',
		'type'            => 'select',
		'choices'         => multi_insure_get_page_choices(),
		'active_callback' => 'multi_insure_is_about_section_and_content_type_page_enabled',
	)
);

// About Section - Button Label.
$wp_customize->add_setting(
	'multi_insure_about_button_label',
	array(
		'default'           => __( 'Read More', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_about_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'multi-insure' ),
		'section'         => 'multi_insure_about_section',
		'settings'        => 'multi_insure_about_button_label',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_about_section_enabled',
	)
);
