<?php
/**
 * Banner Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_banner_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'Banner Section', 'multi-insure' ),
		'priority' => 10,
	)
);

// Banner Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_banner_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_banner_section',
		array(
			'label'    => esc_html__( 'Enable Banner Section', 'multi-insure' ),
			'section'  => 'multi_insure_banner_section',
			'settings' => 'multi_insure_enable_banner_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_banner_section',
		array(
			'selector' => '#multi_insure_banner_section .section-link',
			'settings' => 'multi_insure_enable_banner_section',
		)
	);
}

// Banner Section - Posts Button Label.
$wp_customize->add_setting(
	'multi_insure_banner_button_label',
	array(
		'default'           => __( 'Learn More', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_banner_button_label',
	array(
		'label'           => esc_html__( 'Posts Button Label', 'multi-insure' ),
		'section'         => 'multi_insure_banner_section',
		'settings'        => 'multi_insure_banner_button_label',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
	)
);

// Banner Section - Banner Slider Content Type.
$wp_customize->add_setting(
	'multi_insure_banner_slider_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_banner_slider_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'multi-insure' ),
		'section'         => 'multi_insure_banner_section',
		'settings'        => 'multi_insure_banner_slider_content_type',
		'type'            => 'select',
		'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'multi-insure' ),
			'post' => esc_html__( 'Post', 'multi-insure' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Banner Section - Banner Subtitle.
	$wp_customize->add_setting(
		'multi_insure_banner_subtitle_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'multi_insure_banner_subtitle_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Subtitle %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_banner_section',
			'settings'        => 'multi_insure_banner_subtitle_' . $i,
			'type'            => 'text',
			'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
		)
	);

	// Banner Section - Select Banner Post.
	$wp_customize->add_setting(
		'multi_insure_banner_slider_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_banner_slider_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_banner_section',
			'settings'        => 'multi_insure_banner_slider_content_post_' . $i,
			'active_callback' => 'multi_insure_is_banner_slider_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_post_choices(),
		)
	);

	// Banner Section - Select Banner Page.
	$wp_customize->add_setting(
		'multi_insure_banner_slider_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_banner_slider_content_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Page %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_banner_section',
			'settings'        => 'multi_insure_banner_slider_content_page_' . $i,
			'active_callback' => 'multi_insure_is_banner_slider_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_page_choices(),
		)
	);

	// Banner Section - Button Label.
	$wp_customize->add_setting(
		'multi_insure_banner_button_label_' . $i,
		array(
			'default'           => __( 'Contact Us', 'multi-insure' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'multi_insure_banner_button_label_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Button Label %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_banner_section',
			'settings'        => 'multi_insure_banner_button_label_' . $i,
			'type'            => 'text',
			'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
		)
	);

	// Banner Section - Button Link.
	$wp_customize->add_setting(
		'multi_insure_banner_button_link_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'multi_insure_banner_button_link_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Button Link %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_banner_section',
			'settings'        => 'multi_insure_banner_button_link_' . $i,
			'type'            => 'url',
			'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
		)
	);

	// Banner Section - Horizontal Line.
	$wp_customize->add_setting(
		'multi_insure_banner_horizontal_line_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new Multi_Insure_Customize_Horizontal_Line(
			$wp_customize,
			'multi_insure_banner_horizontal_line_' . $i,
			array(
				'section'         => 'multi_insure_banner_section',
				'settings'        => 'multi_insure_banner_horizontal_line_' . $i,
				'active_callback' => 'multi_insure_is_banner_slider_section_enabled',
				'type'            => 'hr',
			)
		)
	);

}
