<?php
/**
 * Insurers Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_insurers_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'Insurers Bar Section', 'multi-insure' ),
		'priority' => 40,
	)
);

// Insurers Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_insurers_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_insurers_section',
		array(
			'label'    => esc_html__( 'Enable Insurers Section', 'multi-insure' ),
			'section'  => 'multi_insure_insurers_section',
			'settings' => 'multi_insure_enable_insurers_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_insurers_section',
		array(
			'selector' => '#multi_insure_insurers_section .section-link',
			'settings' => 'multi_insure_enable_insurers_section',
		)
	);
}

// Insurers Section - Insurers Image.
$wp_customize->add_setting(
	'multi_insure_insurers_image',
	array(
		'sanitize_callback' => 'multi_insure_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'multi_insure_insurers_image',
		array(
			'label'           => esc_html__( 'Insurers Image', 'multi-insure' ),
			'section'         => 'multi_insure_insurers_section',
			'settings'        => 'multi_insure_insurers_image',
			'active_callback' => 'multi_insure_is_insurers_section_enabled',
		)
	)
);

// Insurers Section - Section Subtitle.
$wp_customize->add_setting(
	'multi_insure_insurers_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_insurers_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'multi-insure' ),
		'section'         => 'multi_insure_insurers_section',
		'settings'        => 'multi_insure_insurers_subtitle',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_insurers_section_enabled',
	)
);

// Insurers Section - Section Title.
$wp_customize->add_setting(
	'multi_insure_insurers_title',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_insurers_title',
	array(
		'label'           => esc_html__( 'Section Title', 'multi-insure' ),
		'section'         => 'multi_insure_insurers_section',
		'settings'        => 'multi_insure_insurers_title',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_insurers_section_enabled',
	)
);

for ( $i = 1; $i <= 4; $i++ ) {

	// Insurers Section - Insurers Label.
	$wp_customize->add_setting(
		'multi_insure_insurers_label_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'multi_insure_insurers_label_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Label %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_insurers_section',
			'settings'        => 'multi_insure_insurers_label_' . $i,
			'type'            => 'text',
			'active_callback' => 'multi_insure_is_insurers_section_enabled',
		)
	);

	// Insurers Section - Insurers Value.
	$wp_customize->add_setting(
		'multi_insure_insurers_value_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_insurers_value_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Value %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_insurers_section',
			'settings'        => 'multi_insure_insurers_value_' . $i,
			'type'            => 'number',
			'input_attrs'     => array( 'min' => 1 ),
			'active_callback' => 'multi_insure_is_insurers_section_enabled',
		)
	);

	// Insurers Section - Horizontal Line.
	$wp_customize->add_setting(
		'multi_insure_insurers_horizontal_line_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new Multi_Insure_Customize_Horizontal_Line(
			$wp_customize,
			'multi_insure_insurers_horizontal_line_' . $i,
			array(
				'section'         => 'multi_insure_insurers_section',
				'settings'        => 'multi_insure_insurers_horizontal_line_' . $i,
				'active_callback' => 'multi_insure_is_insurers_section_enabled',
				'type'            => 'hr',
			)
		)
	);

}
