<?php
/**
 * Latest News Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_latest_news_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'Latest News Section', 'multi-insure' ),
		'priority' => 70,
	)
);

// Latest News Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_latest_news_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_latest_news_section',
		array(
			'label'    => esc_html__( 'Enable Latest News Section', 'multi-insure' ),
			'section'  => 'multi_insure_latest_news_section',
			'settings' => 'multi_insure_enable_latest_news_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_latest_news_section',
		array(
			'selector' => '#multi_insure_latest_news_section .section-link',
			'settings' => 'multi_insure_enable_latest_news_section',
		)
	);
}

// Latest News Section - Section Subtitle.
$wp_customize->add_setting(
	'multi_insure_latest_news_section_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_latest_news_section_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'multi-insure' ),
		'section'         => 'multi_insure_latest_news_section',
		'settings'        => 'multi_insure_latest_news_section_subtitle',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_latest_news_section_enabled',
	)
);

// Latest News Section - Section Title.
$wp_customize->add_setting(
	'multi_insure_latest_news_section_title',
	array(
		'default'           => __( 'Latest From News', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_latest_news_section_title',
	array(
		'label'           => esc_html__( 'Section Title', 'multi-insure' ),
		'section'         => 'multi_insure_latest_news_section',
		'settings'        => 'multi_insure_latest_news_section_title',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_latest_news_section_enabled',
	)
);

// Latest News Section - Content Type.
$wp_customize->add_setting(
	'multi_insure_latest_news_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_latest_news_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'multi-insure' ),
		'section'         => 'multi_insure_latest_news_section',
		'settings'        => 'multi_insure_latest_news_content_type',
		'type'            => 'select',
		'active_callback' => 'multi_insure_is_latest_news_section_enabled',
		'choices'         => array(
			'post'     => esc_html__( 'Post', 'multi-insure' ),
			'category' => esc_html__( 'Category', 'multi-insure' ),
		),
	)
);

// Latest News Section - Select Latest News Category.
$wp_customize->add_setting(
	'multi_insure_latest_news_content_category',
	array(
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_latest_news_content_category',
	array(
		'label'           => esc_html__( 'Select Category', 'multi-insure' ),
		'section'         => 'multi_insure_latest_news_section',
		'settings'        => 'multi_insure_latest_news_content_category',
		'active_callback' => 'multi_insure_is_latest_news_section_and_content_type_category_enabled',
		'type'            => 'select',
		'choices'         => multi_insure_get_post_cat_choices(),
	)
);

for ( $i = 1; $i <= 4; $i++ ) {
	// Latest News Section - Select Post.
	$wp_customize->add_setting(
		'multi_insure_latest_news_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_latest_news_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_latest_news_section',
			'settings'        => 'multi_insure_latest_news_content_post_' . $i,
			'active_callback' => 'multi_insure_is_latest_news_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_post_choices(),
		)
	);

}
