<?php
/**
 * Service Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_service_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'Service Section', 'multi-insure' ),
		'priority' => 30,
	)
);

// Service Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_service_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_service_section',
		array(
			'label'    => esc_html__( 'Enable Service Section', 'multi-insure' ),
			'section'  => 'multi_insure_service_section',
			'settings' => 'multi_insure_enable_service_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_service_section',
		array(
			'selector' => '#multi_insure_service_section .section-link',
			'settings' => 'multi_insure_enable_service_section',
		)
	);
}

// Service Section - Background Image.
$wp_customize->add_setting(
	'multi_insure_service_bg_image',
	array(
		'sanitize_callback' => 'multi_insure_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'multi_insure_service_bg_image',
		array(
			'label'           => esc_html__( 'Background Image', 'multi-insure' ),
			'section'         => 'multi_insure_service_section',
			'settings'        => 'multi_insure_service_bg_image',
			'active_callback' => 'multi_insure_is_service_section_enabled',
		)
	)
);

// Service Section - Section Subtitle.
$wp_customize->add_setting(
	'multi_insure_service_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_service_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'multi-insure' ),
		'section'         => 'multi_insure_service_section',
		'settings'        => 'multi_insure_service_subtitle',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_service_section_enabled',
	)
);

// Service Section - Section Title.
$wp_customize->add_setting(
	'multi_insure_service_title',
	array(
		'default'           => __( 'What We Do For You', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_service_title',
	array(
		'label'           => esc_html__( 'Section Title', 'multi-insure' ),
		'section'         => 'multi_insure_service_section',
		'settings'        => 'multi_insure_service_title',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_service_section_enabled',
	)
);

// Service Section - Number of Posts.
$wp_customize->add_setting(
	'multi_insure_service_excerpt_length',
	array(
		'default'           => 20,
		'sanitize_callback' => 'multi_insure_sanitize_number_range',
		'validate_callback' => 'multi_insure_validate_excerpt_length',
	)
);

$wp_customize->add_control(
	'multi_insure_service_excerpt_length',
	array(
		'label'           => esc_html__( 'Excerpt Length (no. of words)', 'multi-insure' ),
		'description'     => esc_html__( 'Note: Min 1 & Max 100. Please input the valid number and save. Then refresh the page to see the change.', 'multi-insure' ),
		'section'         => 'multi_insure_service_section',
		'settings'        => 'multi_insure_service_excerpt_length',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 1,
			'max' => 100,
		),
		'active_callback' => 'multi_insure_is_service_section_enabled',
	)
);

// Service Section - Content Type.
$wp_customize->add_setting(
	'multi_insure_service_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_service_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'multi-insure' ),
		'section'         => 'multi_insure_service_section',
		'settings'        => 'multi_insure_service_content_type',
		'type'            => 'select',
		'active_callback' => 'multi_insure_is_service_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'multi-insure' ),
			'post' => esc_html__( 'Post', 'multi-insure' ),
		),
	)
);

for ( $i = 1; $i <= 6; $i++ ) {

	// Service Section - Services Icons.
	$wp_customize->add_setting(
		'multi_insure_service_icon_' . $i,
		array(
			'sanitize_callback' => 'multi_insure_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'multi_insure_service_icon_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Service Icon %d', 'multi-insure' ), $i ),
				'section'         => 'multi_insure_service_section',
				'settings'        => 'multi_insure_service_icon_' . $i,
				'active_callback' => 'multi_insure_is_service_section_enabled',
			)
		)
	);

	// Service Section - Select Post.
	$wp_customize->add_setting(
		'multi_insure_service_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_service_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'multi-insure' ) . $i,
			'section'         => 'multi_insure_service_section',
			'settings'        => 'multi_insure_service_content_post_' . $i,
			'active_callback' => 'multi_insure_is_service_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_post_choices(),
		)
	);

	// Service Section - Select Page.
	$wp_customize->add_setting(
		'multi_insure_service_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_service_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'multi-insure' ) . $i,
			'section'         => 'multi_insure_service_section',
			'settings'        => 'multi_insure_service_content_page_' . $i,
			'active_callback' => 'multi_insure_is_service_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_page_choices(),
		)
	);

}

// Service Section - Button Label.
$wp_customize->add_setting(
	'multi_insure_service_button_label',
	array(
		'default'           => __( 'View All', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_service_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'multi-insure' ),
		'section'         => 'multi_insure_service_section',
		'settings'        => 'multi_insure_service_button_label',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_service_section_enabled',
	)
);

// Service Section - Button URL.
	$wp_customize->add_setting(
		'multi_insure_service_button_url',
		array(
			'default'           => '#',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'multi_insure_service_button_url',
		array(
			'label'           => esc_html__( 'Button Url', 'multi-insure' ),
			'section'         => 'multi_insure_service_section',
			'settings'        => 'multi_insure_service_button_url',
			'type'            => 'url',
			'active_callback' => 'multi_insure_is_service_section_enabled',
		)
	);
