<?php
/**
 * Team Section
 *
 * @package Multi_Insure
 */

$wp_customize->add_section(
	'multi_insure_team_section',
	array(
		'panel'    => 'multi_insure_front_page_options',
		'title'    => esc_html__( 'Team Section', 'multi-insure' ),
		'priority' => 50,
	)
);

// Team Section - Enable Section.
$wp_customize->add_setting(
	'multi_insure_enable_team_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'multi_insure_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Multi_Insure_Toggle_Switch_Custom_Control(
		$wp_customize,
		'multi_insure_enable_team_section',
		array(
			'label'    => esc_html__( 'Enable Team Section', 'multi-insure' ),
			'section'  => 'multi_insure_team_section',
			'settings' => 'multi_insure_enable_team_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'multi_insure_enable_team_section',
		array(
			'selector' => '#multi_insure_team_section .section-link',
			'settings' => 'multi_insure_enable_team_section',
		)
	);
}

// Team Section - Section Subtitle.
$wp_customize->add_setting(
	'multi_insure_team_section_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_team_section_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'multi-insure' ),
		'section'         => 'multi_insure_team_section',
		'settings'        => 'multi_insure_team_section_subtitle',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_team_section_enabled',
	)
);

// Team Section - Section Title.
$wp_customize->add_setting(
	'multi_insure_team_section_title',
	array(
		'default'           => __( 'Meet Our volunteers', 'multi-insure' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'multi_insure_team_section_title',
	array(
		'label'           => esc_html__( 'Section Title', 'multi-insure' ),
		'section'         => 'multi_insure_team_section',
		'settings'        => 'multi_insure_team_section_title',
		'type'            => 'text',
		'active_callback' => 'multi_insure_is_team_section_enabled',
	)
);

// Team Section - Content Type.
$wp_customize->add_setting(
	'multi_insure_team_content_type',
	array(
		'default'           => 'post',
		'sanitize_callback' => 'multi_insure_sanitize_select',
	)
);

$wp_customize->add_control(
	'multi_insure_team_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'multi-insure' ),
		'section'         => 'multi_insure_team_section',
		'settings'        => 'multi_insure_team_content_type',
		'type'            => 'select',
		'active_callback' => 'multi_insure_is_team_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'multi-insure' ),
			'post' => esc_html__( 'Post', 'multi-insure' ),
		),
	)
);

for ( $i = 1; $i <= 4; $i++ ) {
	// Team Section - Select Post.
	$wp_customize->add_setting(
		'multi_insure_team_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_team_content_post_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Post %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_team_section',
			'settings'        => 'multi_insure_team_content_post_' . $i,
			'active_callback' => 'multi_insure_is_team_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_post_choices(),
		)
	);

	// Team Section - Select Page.
	$wp_customize->add_setting(
		'multi_insure_team_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'multi_insure_team_content_page_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Select Page %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_team_section',
			'settings'        => 'multi_insure_team_content_page_' . $i,
			'active_callback' => 'multi_insure_is_team_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => multi_insure_get_page_choices(),
		)
	);

	// Team Section - Designation.
	$wp_customize->add_setting(
		'multi_insure_team_designation_' . $i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'multi_insure_team_designation_' . $i,
		array(
			'label'           => sprintf( esc_html__( 'Designation %d', 'multi-insure' ), $i ),
			'section'         => 'multi_insure_team_section',
			'settings'        => 'multi_insure_team_designation_' . $i,
			'active_callback' => 'multi_insure_is_team_section_enabled',
		)
	);

	// Team Section - Social Links.
	$wp_customize->add_setting(
		'multi_insure_team_social_links_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);
	$wp_customize->add_control(
		new Multi_Insure_Sortable_Repeater_Custom_Control(
			$wp_customize,
			'multi_insure_team_social_links_' . $i,
			array(
				'label'           => sprintf( esc_html__( 'Social Icons %d', 'multi-insure' ), $i ),
				'section'         => 'multi_insure_team_section',
				'button_labels'   => array(
					'add' => __( 'Add', 'multi-insure' ),
				),
				'active_callback' => 'multi_insure_is_team_section_enabled',
			)
		)
	);
}
