<?php

if ( ! get_theme_mod( 'multi_insure_enable_about_section', false ) ) {
	return;
}

$multi_insure_content_id = array();

$multi_insure_content_type = get_theme_mod( 'multi_insure_about_content_type', 'page' );

if ( 'post' === $multi_insure_content_type ) {
	$multi_insure_content_id[] = get_theme_mod( 'multi_insure_about_content_post' );
} else {
	$multi_insure_content_id[] = get_theme_mod( 'multi_insure_about_content_page' );
}
$multi_insure_args = array(
	'post_type'           => $multi_insure_content_type,
	'post__in'            => array_filter( $multi_insure_content_id ),
	'orderby'             => 'post__in',
	'posts_per_page'      => absint( 1 ),
	'ignore_sticky_posts' => true,
);
$multi_insure_args = apply_filters( 'multi_insure_about_section_content', $multi_insure_args );

multi_insure_render_about_section( $multi_insure_args );

/**
 * Render About Us Section
 */

function multi_insure_render_about_section( $multi_insure_args ) {
	$multi_insure_query = new WP_Query( $multi_insure_args );
	if ( $multi_insure_query->have_posts() ) :
		while ( $multi_insure_query->have_posts() ) :
			$multi_insure_query->the_post();

			$multi_insure_section_subtitle = get_theme_mod( 'multi_insure_about_section_subtitle', '' );
			$multi_insure_button_label     = get_theme_mod( 'multi_insure_about_button_label', __( 'Read More', 'multi-insure' ) );
			?>
			<section id="multi_insure_about_section" class="multi-insure-about-us multi-insure-section">
				<?php
				if ( is_customize_preview() ) :
					multi_insure_section_link( 'multi_insure_about_section' );
				endif;
				?>
				<div class="multi-insure-wrapper">
					<div class="multi-insure-about-us-container">
						<div class="multi-insure-about-us-left-container" data-aos="zoom-in-up" data-aos-duration="1000">
							<div class="important-image-container">
								<?php the_post_thumbnail( 'post-thumbnail' ); ?>
							</div>
						</div>
						<div class="multi-insure-about-us-right-container" data-aos="zoom-in-up" data-aos-duration="1000">
							<div class="title-heading ">
								<?php if ( ! empty( $multi_insure_section_subtitle ) ) { ?>
									<p><?php echo esc_html( $multi_insure_section_subtitle ); ?></p>
								<?php } ?>
								<h2><?php the_title(); ?></h2>
							</div>
							<div class="multi-insure-about-us-paragraph">
								<p><?php echo wp_kses_post( wp_trim_words( get_the_content(), 80 ) ); ?></p>
							</div>
							<?php if ( ! empty( $multi_insure_button_label ) ) { ?>
								<div class="insure-about-us-button">
									<a href="<?php the_permalink(); ?>" class="multi-insure-button"><?php echo esc_html( $multi_insure_button_label ); ?></a>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</section>
			<?php
		endwhile;
		wp_reset_postdata();
	endif;
}
