<?php

if ( ! get_theme_mod( 'multi_insure_enable_latest_news_section', false ) ) {
	return;
}

$multi_insure_latest_news_content_ids  = array();
$multi_insure_latest_news_content_type = get_theme_mod( 'multi_insure_latest_news_content_type', 'post' );

if ( $multi_insure_latest_news_content_type === 'post' ) {
	for ( $multi_insure_i = 1; $multi_insure_i <= 4; $multi_insure_i++ ) {
		$multi_insure_latest_news_content_ids[] = get_theme_mod( 'multi_insure_latest_news_content_post_' . $multi_insure_i );
	}
	$multi_insure_args = array(
		'post_type'           => $multi_insure_latest_news_content_type,
		'post__in'            => array_filter( $multi_insure_latest_news_content_ids ),
		'orderby'             => 'post__in',
		'posts_per_page'      => absint( 4 ),
		'ignore_sticky_posts' => true,
	);
} else {
	$multi_insure_cat_content_id = get_theme_mod( 'multi_insure_latest_news_content_category' );
	$multi_insure_args           = array(
		'cat'            => $multi_insure_cat_content_id,
		'posts_per_page' => absint( 4 ),
	);
}
$multi_insure_args = apply_filters( 'multi_insure_latest_news_section_args', $multi_insure_args );

multi_insure_render_latest_news_section( $multi_insure_args );

/**
 * Render Latest News Section.
 */
function multi_insure_render_latest_news_section( $multi_insure_args ) {
	$multi_insure_latest_news_subtitle = get_theme_mod( 'multi_insure_latest_news_section_subtitle', '' );
	$multi_insure_latest_news_title    = get_theme_mod( 'multi_insure_latest_news_section_title', __( 'Latest From News', 'multi-insure' ) );
	?>

	<section id="multi_insure_latest_news_section" class="multi-insure-latest-news multi-insure-section latest-news-style-1">
		<?php
		if ( is_customize_preview() ) :
			multi_insure_section_link( 'multi_insure_latest_news_section' );
		endif;
		?>
		<div class="multi-insure-wrapper">
			<?php if ( ! empty( $multi_insure_latest_news_subtitle || $multi_insure_latest_news_title ) ) { ?>
				<div class="title-heading ">
					<p><?php echo esc_html( $multi_insure_latest_news_subtitle ); ?></p>
					<h2><?php echo esc_html( $multi_insure_latest_news_title ); ?></h2>
				</div>
				<?php
			}
			$multi_insure_query = new WP_Query( $multi_insure_args );
			if ( $multi_insure_query->have_posts() ) {
				?>
				<div class="multi-insure-latest-news-cards slick-button latest-news-button" data-slick='{"autoplay": false }'>
					<?php
					while ( $multi_insure_query->have_posts() ) :
						$multi_insure_query->the_post();
						?>
						<div class="multi-insure-latest-news-card">
							<div class="latest-news-card-image">
								<?php the_post_thumbnail( 'post-thumbnail' ); ?>
							</div>
							<div class="latest-news-card-texts">
								<div class="card-text-left">
									<h2 class="date"><?php echo esc_html( get_the_date( 'd' ) ); ?></h2>
									<h3 class="month"><?php echo esc_html( get_the_date( 'M' ) ); ?></h3>
								</div>
								<div class="card-text-right">
									<h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
									<div class="card-user">
										<div class="client">
											<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>">
												<i class="fa fa-user-o" aria-hidden="true"></i>
												<span><?php echo esc_html( get_the_author() ); ?></span>
											</a>
										</div>
										<div class="comments">
											<i class="fa fa-comment-o" aria-hidden="true"></i>
											<p><?php echo absint( get_comments_number( get_the_ID() ) ); ?></p>
										</div>
									</div>
								</div>
							</div>
						</div>
						<?php
					endwhile;
					wp_reset_postdata();
					?>
				</div>
			<?php } ?>
		</div>
	</section>

	<?php
}
