<?php

if ( ! get_theme_mod( 'multi_insure_enable_service_section', false ) ) {
	return;
}

$multi_insure_content_ids  = array();
$multi_insure_content_type = get_theme_mod( 'multi_insure_service_content_type', 'page' );

for ( $multi_insure_i = 1; $multi_insure_i <= 6; $multi_insure_i++ ) {
	$multi_insure_content_ids[] = get_theme_mod( 'multi_insure_service_content_' . $multi_insure_content_type . '_' . $multi_insure_i );
}

$multi_insure_args = array(
	'post_type'           => $multi_insure_content_type,
	'post__in'            => array_filter( $multi_insure_content_ids ),
	'orderby'             => 'post__in',
	'posts_per_page'      => absint( 6 ),
	'ignore_sticky_posts' => true,
);

$multi_insure_args = apply_filters( 'multi_insure_service_section_args', $multi_insure_args );

multi_insure_render_service_section( $multi_insure_args );

/**
 * Render Service Section.
 */
function multi_insure_render_service_section( $multi_insure_args ) {
	$multi_insure_background_image = get_theme_mod( 'multi_insure_service_bg_image', '' );
	$multi_insure_section_title    = get_theme_mod( 'multi_insure_service_title', __( 'What We Do For You', 'multi-insure' ) );
	$multi_insure_section_subtitle = get_theme_mod( 'multi_insure_service_subtitle', '' );
	$multi_insure_excerpt_length   = get_theme_mod( 'multi_insure_service_excerpt_length', 20 );
	$multi_insure_button_label     = get_theme_mod( 'multi_insure_service_button_label', __( 'View All', 'multi-insure' ) );
	$multi_insure_button_url       = get_theme_mod( 'multi_insure_service_button_url', '#' );

	?>

	<section id="multi_insure_service_section" class="multi-insure-ins-services  insure-image-background" style="background-color: '#0b2033';">
		<?php
		if ( is_customize_preview() ) :
			multi_insure_section_link( 'multi_insure_service_section' );
		endif;
		?>
		<?php if ( ! empty( $multi_insure_background_image ) ) : ?>
			<div class="multi-insure-ins-services-image">
				<img src="<?php echo esc_url( $multi_insure_background_image ); ?>" alt="<?php esc_attr_e( 'service background image', 'multi-insure' ); ?>">
			</div>
		<?php endif; ?>
		<div class="multi-insure-wrapper">
			<div class="multi-insure-ins-services-wrapper" >
				<div class="multi-insure-ins-services-heading-wrapper">
					<?php if ( ! empty( $multi_insure_section_subtitle || $multi_insure_section_title ) ) { ?>
						<div class="title-heading  title-heading-alternate">
							<p><?php echo esc_html( $multi_insure_section_subtitle ); ?></p>
							<H2><?php echo esc_html( $multi_insure_section_title ); ?></H2>
						</div>
					<?php } ?>
				</div>	
				<?php
				$multi_insure_query = new WP_Query( $multi_insure_args );
				if ( $multi_insure_query->have_posts() ) :
					?>
					<div class="multi-insure-ins-services-card-wrapper">
						<?php
						$multi_insure_i = 1;
						while ( $multi_insure_query->have_posts() ) :
							$multi_insure_query->the_post();
							$multi_insure_service_icon = get_theme_mod( 'multi_insure_service_icon_' . $multi_insure_i, '' );
							?>
							<div class="multi-insure-ins-card" data-aos-delay="<?php echo esc_attr( $multi_insure_i * 300 ); ?>" data-aos="fade-up" data-aos-duration="800">
								<div class="multi-insure-ins-card-inside">
									<div class="ins-services-card-logo">
										<img src="<?php echo esc_url( $multi_insure_service_icon ); ?>">
									</div>
									<div class="ins-services-card-texts">
										<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4> 
										<p><?php echo wp_kses_post( wp_trim_words( get_the_content(), $multi_insure_excerpt_length ) ); ?></p>
									</div>	
								</div>
							</div>
							<?php
							$multi_insure_i++;
						endwhile;
						wp_reset_postdata();
						?>
					</div>
					<?php
				endif;
				if ( ! empty( $multi_insure_button_label ) ) :
					?>
					<div class="multi-insure-ins-services-button">
						<a href="<?php echo esc_url( $multi_insure_button_url ); ?>" class="multi-insure-button "><?php echo esc_html( $multi_insure_button_label ); ?></a>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</section>

	<?php

}
